@@ -12,7 +12,7 @@ creategame ()
    int             i, j, k;
    int             nplanets;
    double          x, y, dx, dy;
-   double          tmp;
+   /*double          tmp;*/
    player         *P;
    planet         *p;
 
