@@ -187,6 +187,9 @@ struct player {
    int             namecase;
    int             lastorders;
    int             fleettables;
+   int             autounload;
+   int             prodtable;
+   int             sortgroups;
    strlist        *orders;
    strlist        *messages;
    strlist        *mistakes;
@@ -801,7 +804,10 @@ loadgame(char *name)
       P->mx = rf();
       P->my = rf();
       P->msize = rf();
+      P->prodtable = ri();
+      P->autounload = ri();
       P->fleettables = ri();
+      P->sortgroups = ri();
       P->underscores = ri();
       P->twocol = ri();
       P->namecase = ri();
@@ -1746,6 +1752,18 @@ processturns(char *ordersfilename)
 			i = 0;
 			ns = getstr(0);
 		     }
+		     if (!strcmpl(ns, "prodtable")) {
+			P->prodtable = i;
+			break;
+		     }
+		     if (!strcmpl(ns, "autounload")) {
+			P->autounload = i;
+			break;
+		     }
+		     if (!strcmpl(ns, "sortgroups")) {
+			P->sortgroups = i;
+			break;
+		     }
 		     if (!strcmpl(ns, "fleettables")) {
 			P->fleettables = i;
 			break;
@@ -2329,9 +2347,9 @@ main(int argc, char *argv[])
    dfd = opendir(".");
    srand();
    randno = (unsigned long) rand();
-   fprintf(stderr,"Galaxy v3.41  Order Checker by Robert Stone\n\
+   fprintf(stderr,"Galaxy v3.40  Order Checker by Robert Stone\n\
 Copyright 1991-1992 by Russell Wallace and Robert Stone\n\
-Revised for Galaxy v3.41 by Kevin Pankhurst\n\
+Revised for Galaxy v3.40 by Kevin Pankhurst\n\
 Minor mods by Robert Novak for his games\n");
    if(argc > 1) {
 	processturns(argv[1]);
