@@ -390,8 +390,8 @@ fightphase ()
                         continue;
                      if (!cankill(fightgroups[agroup], fightgroups[tgroup]))
                         continue;
-                     if (atwar(groupplayers[agroup], groupplayers[tgroup]) ||
-                         atwar(groupplayers[tgroup], groupplayers[agroup]) &&
+                     if ((atwar(groupplayers[agroup], groupplayers[tgroup]) ||
+                         atwar(groupplayers[tgroup], groupplayers[agroup])) &&
                          fightgroups[tgroup]->type->attacks)
                         moretargets = 1;
                      else if (atwar(groupplayers[tgroup], groupplayers[agroup]))
@@ -416,8 +416,8 @@ fightphase ()
                         assert(tgroup < ngroups);
                      }
                      assert(fightgroups[tgroup]->ships);
-                     if (atwar(groupplayers[agroup], groupplayers[tgroup]) ||
-                         atwar(groupplayers[tgroup], groupplayers[agroup]) &&
+                     if ((atwar(groupplayers[agroup], groupplayers[tgroup]) ||
+                         atwar(groupplayers[tgroup], groupplayers[agroup])) &&
                          fightgroups[tgroup]->type->attacks)
                         foundtarget = 1;
                      else if (atwar(groupplayers[tgroup], groupplayers[agroup]))
@@ -466,8 +466,8 @@ fightphase ()
                      if (!fightgroups[tgroup]->ships ||
                          !cankill(fightgroups[agroup], fightgroups[tgroup]))
                         continue;
-                     if (atwar(groupplayers[agroup], groupplayers[tgroup]) ||
-                         atwar(groupplayers[tgroup], groupplayers[agroup]) &&
+                     if ((atwar(groupplayers[agroup], groupplayers[tgroup]) ||
+                         atwar(groupplayers[tgroup], groupplayers[agroup])) &&
                          fightgroups[tgroup]->type->attacks)
                         moretargets = 1;
                      else if (atwar(groupplayers[tgroup], groupplayers[agroup]))
@@ -935,7 +935,7 @@ void
 sortphase()
 #endif
 {
-   group *g, *g2, *newgroup;
+   group *g, *newgroup;
    fleetname *fl;
    player *P;
    planet *Pl;
