@@ -425,7 +425,7 @@ int n;
    char            buf[10];
 
    sprintf(buf, "%d", n);
-   sprintf(numberformat, "[%%%dd]", strlen(buf));
+   sprintf(numberformat, "[%%%dd]", (int) strlen(buf));
    numbercount = 0;
 }
 
@@ -481,7 +481,13 @@ planet * p;
    ff(p->col);
 }
 
-void printproduction (planet *p)
+#ifdef __STDC__
+void 
+printproduction (planet * p)
+#else
+void printproduction (p)
+planet * p;
+#endif
 {
    float mass;
    float theshipmass;
