@@ -17,14 +17,14 @@ extern   int          lastc;
 
 int      memicmp _PROTO((char c1[256], char c2[256], int val));
 int      strcmpl _PROTO((char c1[100], char c2[100]));
-char *   findnext _PROTO(());
+char *   findnext _PROTO((void));
 char *   findfirst _PROTO((char *dir));
 void *   numtop _PROTO((void *base, char *s));
 void     removelist _PROTO((void *_base, void *_p));
 /* int      _atoi _PROTO((char *s)); */
 /* int      rand _PROTO((void)); */
 FILE *   Fopen _PROTO((char *filename, char *mode));
-void *   alloc _PROTO((int n));
+void *   alloc _PROTO((unsigned int n));
 void     addlist _PROTO((void *_base, void *_p));
 void     freelist _PROTO((void *base));
 void     freestrlist _PROTO((strlist * s));
@@ -92,6 +92,7 @@ void     unloadcol _PROTO((planet * p, double x, player * P));
 void     unloadgroup _PROTO((group * g, player * P));
 void     joinphase _PROTO((void));
 void     sortphase _PROTO((void));
+void     fleetphase _PROTO((void));
 double   calcdefense _PROTO((group * target));
 int      cankill _PROTO((group * attack, group * target));
 int      kill _PROTO((group * attack, group * target));
