@@ -160,7 +160,11 @@ player * P;
 
    f = Fopen(buf, "w");
 
+#ifdef CHECKER
+   printf("Writing forecast file %x...\n", buf);
+#else
    printf("Writing report file %s...\n", buf);
+#endif
 
    cap_gamename = strdup(gamename);
    cap_gamename[0] = toupper(cap_gamename[0]);
@@ -168,7 +172,14 @@ player * P;
    strcpy(buf, P->name);
    ckunderscores(buf);
 
+#ifdef CHECKER
+   fprintf(f, "\t\tGalaxy Game %s Turn %d FORECAST for %s\n\n\
+This forecast is suspect and is provided merely for your information.\n\
+Status reports for other players are inaccurate in most cases. Use at\n\
+your own risk!\n\n",
+#else
    fprintf(f, "\t\tGalaxy Game %s Turn %d Report for %s\n", 
+#endif
 	cap_gamename, turn, buf);
    underscores = 0;
    twocol = P->twocol;
@@ -224,7 +235,7 @@ player * P;
       }
    }
 
-   fbegin("Mistakes", "xx");
+   fbegin("MISTAKES", "xx");
    for (s = P->mistakes; s; s = s->next) {
       if (s->s[0][0] == '#')
          fs(s->s[0] + 1);
@@ -237,14 +248,26 @@ player * P;
 
    underscores = P->underscores;
 
+#ifdef CHECKER
+   fbegin("Status of Players--ONLY YOURS IS ACCURATE", "xffffffix");
+#else
    fbegin("Status of Players", "xffffffix");
+#endif
    flabels = "NDWSCPI#R";
    for (P2 = players; P2; P2 = P2->next) {
+#ifndef CHECKER
       fs(P2->name);
       ff(P2->drive);
       ff(P2->weapons);
       ff(P2->shields);
       ff(P2->cargo);
+#else
+      fs(P2->name);
+      ff(P == P2 ? P2->drive : 0.0);
+      ff(P == P2 ? P2->weapons : 0.0);
+      ff(P == P2 ? P2->shields : 0.0);
+      ff(P == P2 ? P2->cargo : 0.0);
+#endif /* ifndef CHECKER */
       pop = 0;
       ind = 0;
       i = 0;
@@ -254,9 +277,15 @@ player * P;
             ind += p->ind;
             i++;
          }
+#ifndef CHECKER
       ff(pop);
       ff(ind);
       fi(i);
+#else
+      ff(P == P2 ? pop : 0.0);
+      ff(P == P2 ? ind : 0.0);
+      fi(P == P2 ? i : 0);
+#endif /* ifndef CHECKER */
       fs(P == P2 ? "" : (atwar(P, P2) ? "War" : "Peace"));
    }
    fend();
@@ -266,7 +295,7 @@ player * P;
    for (t = P->shiptypes; t; t = t->next)
       printshiptype(t);
    fend();
-
+#ifndef CHECKER
    for (P2 = players; P2; P2 = P2->next)
       if (P2 != P) {
          for (t = P2->shiptypes; t; t = t->next)
@@ -430,7 +459,7 @@ player * P;
                ff(shipmass(g) * g->ships);
             }
    fend();
-
+#endif   /* for ifndef CHECKER */
    fbegin("Your Planets", "xffffffxfff");
    flabels = "NXYSPIRP$MC";
    for (p = planets; p; p = p->next)
@@ -467,7 +496,7 @@ player * P;
        fs("SET");
    }
    fend();
-
+#ifndef CHECKER
    for (P2 = players; P2; P2 = P2->next)
       if (P2 != P) {
          strcpy(buf, P2->name);
@@ -506,7 +535,7 @@ player * P;
          }
       }
    fend();
-
+#endif   /* for ifndef CHECKER */
    if (P->fleettables) {
       fbegin("Your Groups", "iixffffxfxf"); 
       flabels = "G#TDWSCTQDR";
@@ -542,7 +571,7 @@ player * P;
       }
       fend();
    }
-
+#ifndef CHECKER
    for (P2 = players; P2; P2 = P2->next)
       if (P2 != P) {
          strcpy(buf, P2->name);
@@ -555,5 +584,6 @@ player * P;
                printgroup(P2, g, 1, 0);
          fend();
       }
+#endif   /* for ifndef CHECKER */
    fclose(f);
 }
