@@ -309,11 +309,11 @@ char *mode;
 
 #ifdef __STDC__
 void           *
-alloc(int n)
+alloc(unsigned int n)
 #else
 void           *
 alloc(n)
-int n;
+unsigned int n;
 #endif
 {
    void           *p;
